package com.hungraim.ltc.account.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hungraim.ltc.account.dao.ChDisabAccountsMapper;
import com.hungraim.ltc.account.service.AccountService;
import com.hungraim.ltc.account.service.BaseAccountService;
import com.hungraim.ltc.api.AttachFeignService;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndAttach;
import com.hungraim.ltc.pojo.entity.account.ChDisabAccounts;
import com.hungraim.ltc.pojo.vo.account.AccountOperVo;
import com.hungraim.ltc.pojo.vo.account.SrvOrganListReq;
import com.hungraim.ltc.pojo.vo.account.SrvOrganListResp;
import com.hungraim.ltc.util.AttachType;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Service
@AllArgsConstructor
@Slf4j
public class AccountServiceImpl extends ServiceImpl<ChDisabAccountsMapper, ChDisabAccounts> implements AccountService {

    private final AttachFeignService attachFeignService;
    private final BaseAccountService baseAccountService;
    private final ChDisabAccountsMapper disabAccountsMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void addOrUpdateAccount(AccountOperVo accountOperVo) {
        ChDisabAccounts chDisabAccounts = new ChDisabAccounts();
        BeanUtils.copyProperties(accountOperVo, chDisabAccounts);
        chDisabAccounts.setChooseSettle((short) 0); // 是否结算(0未结算，1已结算)
        this.saveOrUpdate(chDisabAccounts);
        accountOperVo.setAccountsId(chDisabAccounts.getAccountsId());
        baseAccountService.updateAttachs(chDisabAccounts.getAccountsId(), accountOperVo.getFileDataList(), AttachType.SRV_ORGAN_ACCOUNT);
    }

    @Override
    public Page<SrvOrganListResp> searchSrvOrganList(SrvOrganListReq srvOrganListReq) {
        List<Long> organIds = baseAccountService.getOrganIds(srvOrganListReq.getOrganId(), srvOrganListReq.getIsInvolveChild());
        return disabAccountsMapper.searchSrvOrganList(new Page<>(srvOrganListReq.getPageNum(), srvOrganListReq.getPageSize()), organIds, srvOrganListReq);
    }

    @Override
    public AccountOperVo getSrvOrganDetail(Long accountsId) {
        AccountOperVo accountOperVo = disabAccountsMapper.getDetailById(accountsId);
        try {
            Result<List<ChFndAttach>> result = attachFeignService.selectAttachs(accountOperVo.getAccountsId(), AttachType.SRV_ORGAN_ACCOUNT.getUploadType());
            if (ResultCode.SUCCESS.getCode().equals(result.getCode())) {
                accountOperVo.setFileDataList(result.getData());
            } else {
                log.error("获取机构结算资料失败：{}", result.getMsg());
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取机构结算资料失败：{}", e.getMessage());
        }
        return accountOperVo;
    }

}
