package com.hungraim.ltc.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.SysConfig.ChCfgSrvOrganType;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndSrvOrganLevel;
import com.hungraim.ltc.pojo.entity.disable.ChCfgSrvEmpCate;
import com.hungraim.ltc.pojo.entity.disable.ChCfgSrvEmpType;
import com.hungraim.ltc.pojo.vo.disable.SrvOrganEmpListVo;
import com.hungraim.ltc.pojo.vo.disable.SrvOrganEmpVo;
import com.hungraim.ltc.pojo.vo.disable.SrvOrganListVo;
import com.hungraim.ltc.pojo.vo.system.SrvOrganVo;
import com.hungraim.ltc.service.SrvEmpCateService;
import com.hungraim.ltc.service.SrvEmpTypeService;
import com.hungraim.ltc.service.SrvOrganEmpService;
import com.hungraim.ltc.service.SrvOrganService;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api.apply/srvOrgan")
@AllArgsConstructor
public class SrvOrganController {

    private final SrvOrganService srvOrganService;

    private final SrvEmpTypeService srvEmpTypeService;

    private final SrvOrganEmpService srvOrganEmpService;

    private final SrvEmpCateService srvEmpCateService;

    /**
     * 分页查询护理机构列表
     *
     * @param pageNum        分页参数
     * @param pageSize       分页参数
     * @param organId        适用机构id
     * @param isInvolveChild 是否包含下层机构
     * @param creditCode     统一社会信用代码
     * @param srvOrganName   护理机构名称
     * @return 返回护理机构列表
     */
    @GetMapping("/list")
    public Result<Page<SrvOrganListVo>> getSrvOrganList(Integer pageNum, Integer pageSize, Long organId, Boolean isInvolveChild, String creditCode, String srvOrganName) {
        Page<SrvOrganListVo> page = new Page<>(pageNum, pageSize);
        page = srvOrganService.getSrvOrganList(page, organId, isInvolveChild, creditCode, srvOrganName);
        return Result.success(page);
    }

    /**
     * 获取所有服务机构等级
     *
     * @return 返回服务机构等级
     */
    @GetMapping("/srvOrganLevels")
    public Result<List<ChFndSrvOrganLevel>> getSrvOrganLevels() {
        List<ChFndSrvOrganLevel> srvOrganLevels = srvOrganService.getSrvOrganLevels();
        return Result.success(srvOrganLevels);
    }

    /**
     * 获取所有服务机构类型
     *
     * @return 返回所有服务机构类型
     */
    @GetMapping("/srvOrganTypes")
    public Result<List<ChCfgSrvOrganType>> getSrvOrganTypes() {
        List<ChCfgSrvOrganType> chCfgSrvOrganTypes = srvOrganService.getSrvOrganTypes();
        return Result.success(chCfgSrvOrganTypes);
    }


    /**
     * 添加护理机构
     *
     * @param srvOrganVo 护理机构包装对象
     * @return 返回操作结果
     */
    @PostMapping("/srvOrgan")
    public Result saveSrvOrgan(SrvOrganVo srvOrganVo) {
        if (StrUtil.isBlank(srvOrganVo.getOrganId()) || StrUtil.isBlank(srvOrganVo.getDistrictProvincial()) || StrUtil.isBlank(srvOrganVo.getDistrictCity()) || StrUtil.isBlank(srvOrganVo.getDistrictArea()) || StrUtil.isBlank(srvOrganVo.getAcptProvincial()) || StrUtil.isBlank(srvOrganVo.getAcptCity()) || StrUtil.isBlank(srvOrganVo.getAcptArea()) || StrUtil.isBlank(srvOrganVo.getAcptStreet()) || StrUtil.isBlank(srvOrganVo.getAcptStreet()) || StrUtil.isBlank(srvOrganVo.getBankDistrictProvincial()) || StrUtil.isBlank(srvOrganVo.getBankDistrictCity()) || StrUtil.isBlank(srvOrganVo.getSrvOrganName()) || StrUtil.isBlank(srvOrganVo.getPermitId()) || null == srvOrganVo.getOrganTypeId() || null == srvOrganVo.getLevelCode() || StrUtil.isBlank(srvOrganVo.getLinkName()) || StrUtil.isBlank(srvOrganVo.getLinkTel()) || StrUtil.isBlank(srvOrganVo.getSrvType()) || null == srvOrganVo.getBunk() || StrUtil.isBlank(srvOrganVo.getUnifiedSocialCreditCode()) || StrUtil.isBlank(srvOrganVo.getSrvType()) || StrUtil.isBlank(srvOrganVo.getAccName()) || StrUtil.isBlank(srvOrganVo.getBankAccCode()) || StrUtil.isBlank(srvOrganVo.getBankAccName()) || StrUtil.isBlank(srvOrganVo.getBankNo()) || StrUtil.isBlank(srvOrganVo.getBankDistrictWebsite()) || null == srvOrganVo.getCardType() || null == srvOrganVo.getFileDataList() || srvOrganVo.getFileDataList().size() < 3) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        // 参数校验通过，调用service添加护理机构
        try {
            srvOrganService.saveOrUpdateSrvOrgan(srvOrganVo);
        } catch (RuntimeException e) {
            return Result.failed(e.getMessage());
        }
        return Result.success();
    }

    /**
     * 修改护理机构
     *
     * @param srvOrganVo 护理机构包装对象
     * @return 返回操作结果
     */
    @PostMapping("/updateSrvOrgan")
    public Result updateSrvOrgan(SrvOrganVo srvOrganVo) {
        if (null == srvOrganVo.getSrvOrganId() || StrUtil.isBlank(srvOrganVo.getOrganId()) || StrUtil.isBlank(srvOrganVo.getDistrictProvincial()) || StrUtil.isBlank(srvOrganVo.getDistrictCity()) || StrUtil.isBlank(srvOrganVo.getDistrictArea()) || StrUtil.isBlank(srvOrganVo.getAcptProvincial()) || StrUtil.isBlank(srvOrganVo.getAcptCity()) || StrUtil.isBlank(srvOrganVo.getAcptArea()) || StrUtil.isBlank(srvOrganVo.getAcptStreet()) || StrUtil.isBlank(srvOrganVo.getAcptStreet()) || StrUtil.isBlank(srvOrganVo.getBankDistrictProvincial()) || StrUtil.isBlank(srvOrganVo.getBankDistrictCity()) || StrUtil.isBlank(srvOrganVo.getSrvOrganName()) || StrUtil.isBlank(srvOrganVo.getPermitId()) || null == srvOrganVo.getOrganTypeId() || null == srvOrganVo.getLevelCode() || StrUtil.isBlank(srvOrganVo.getLinkName()) || StrUtil.isBlank(srvOrganVo.getLinkTel()) || StrUtil.isBlank(srvOrganVo.getSrvType()) || null == srvOrganVo.getBunk() || StrUtil.isBlank(srvOrganVo.getUnifiedSocialCreditCode()) || StrUtil.isBlank(srvOrganVo.getSrvType()) || StrUtil.isBlank(srvOrganVo.getAccName()) || StrUtil.isBlank(srvOrganVo.getBankAccCode()) || StrUtil.isBlank(srvOrganVo.getBankAccName()) || StrUtil.isBlank(srvOrganVo.getBankNo()) || StrUtil.isBlank(srvOrganVo.getBankDistrictWebsite()) || null == srvOrganVo.getCardType() || null == srvOrganVo.getFileDataList() || srvOrganVo.getFileDataList().size() < 3) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        // 参数校验通过，调用service修改护理机构
        srvOrganService.saveOrUpdateSrvOrgan(srvOrganVo);
        return Result.success();
    }

    /**
     * 查询护理机构详情
     *
     * @param srvOrganId 护理机构id
     * @return 返回护理机构详情
     */
    @GetMapping("/srvOrgan")
    public Result<SrvOrganVo> getSrvOrganDetail(Long srvOrganId) {
        if (null == srvOrganId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        SrvOrganVo srvOrganVo = srvOrganService.getSrvOrganDetail(srvOrganId);
        return Result.success(srvOrganVo);
    }

    /**
     * 分页查询护理人员列表
     *
     * @param pageNum        页码参数
     * @param pageSize       页码参数
     * @param organId        适用机构id
     * @param isInvolveChild 是否包含子机构
     * @param empName        人员姓名
     * @param srvOrganName   护理机构名称
     * @param certifNum      身份证号
     * @param isLock         人员状态
     * @param empType        护理人员类型
     * @return 返回列表
     */
    @GetMapping("/srvOrganEmpList")
    public Result<Page<SrvOrganEmpListVo>> getSrvOrganEmpListVo(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize, Long organId, Boolean isInvolveChild, String empName, String srvOrganName, String certifNum, Short isLock, Short empType) {
        Page<SrvOrganEmpListVo> page = new Page<>(pageNum, pageSize);
        page = srvOrganEmpService.getSrvOrganEmpListVo(page, organId, isInvolveChild, empName, srvOrganName, certifNum, isLock, empType);
        return Result.success(page);
    }

    /**
     * 删除护理机构
     *
     * @param srvOrganId 护理机构id
     * @return 返回执行结果
     */
    @DeleteMapping("/srvOrgan")
    public Result<SrvOrganVo> deleteSrvOrgan(Long srvOrganId) {
        if (null == srvOrganId) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        srvOrganService.deleteSrvOrgan(srvOrganId);
        return Result.success();
    }

    /**
     * 获取护理人员的资质列表
     *
     * @param empCateId 护理人员类别id
     * @return 返回列表
     */
    @GetMapping("/srvEmpTypeList")
    public Result<List<ChCfgSrvEmpType>> getSrvEmpTypeList(Integer empCateId) {
        List<ChCfgSrvEmpType> chCfgSrvEmpTypes = srvEmpTypeService.list(new LambdaQueryWrapper<ChCfgSrvEmpType>().eq(null != empCateId, ChCfgSrvEmpType::getEmpCateId, empCateId));
        return Result.success(chCfgSrvEmpTypes);
    }


    /**
     * 修改护理人员的状态
     *
     * @param empId  护理人员id
     * @param isLock 状态  0-有效；1-失效；
     * @return 返回操作状态
     */
    @PutMapping("/status")
    public Result updateSrvEmpStatus(Long empId, Short isLock) {
        if (null == empId || null == isLock) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        srvOrganEmpService.updateSrvEmpStatus(empId, isLock);
        return Result.success();
    }

    /**
     * 获取护理人员类别信息
     *
     * @return 返回护理人员类别列表
     */
    @GetMapping("/srvEmpCateList")
    public Result<List<ChCfgSrvEmpCate>> getSrvEmpCateList() {
        return Result.success(srvEmpCateService.list());
    }

    /**
     * 获取护理人员相关信息
     *
     * @param empId 护理人员id
     * @return 返回护理人员信息
     */
    @GetMapping("/srvOrganEmp")
    public Result<SrvOrganEmpVo> getSrvOrganEmp(Long empId) {
        SrvOrganEmpVo srvOrganEmpVo = srvOrganEmpService.getSrvOrganEmp(empId);
        return Result.success(srvOrganEmpVo);
    }

    /**
     * 保存或修改护理人员对象
     *
     * @param srvOrganEmpVo 护理人员对象参数
     *                      empId:"", // 护理人员id
     *                      organId: "", // 适用机构id
     *                      srvOrganId: "", // 护理机构id
     *                      unifiedSocialCreditCode: "", // 统一社会信用代码
     *                      empName: "", // 护理人员姓名
     *                      certifType: "", // 护理人员证件类型
     *                      certifNum: "", // 护理人员证件号码
     *                      gender: "", // 护理人员性别
     *                      age: "", // 护理人员年龄
     *                      mobilePhone: "", // 护理人员手机号
     *                      empTypeId: "", // 护理人员资质
     *                      srvCateId: "", // 护理人员类别
     *                      empType: '', // 人员类型
     *                      eduId: "", // 文化水平
     *                      fileDataList: [], // 对应数据库中的文件数据列表
     * @return 返回操作结果
     */
    @PostMapping("/srvOrganEmp")
    public Result saveOrUpdateSrvOrganEmp(SrvOrganEmpVo srvOrganEmpVo) {
        if (null == srvOrganEmpVo.getOrganId() || null == srvOrganEmpVo.getSrvOrganId() || StrUtil.isBlank(srvOrganEmpVo.getEmpName()) || StrUtil.isBlank(srvOrganEmpVo.getCertifType()) || StrUtil.isBlank(srvOrganEmpVo.getCertifNum()) || StrUtil.isBlank(srvOrganEmpVo.getGender()) || null == srvOrganEmpVo.getAge() || StrUtil.isBlank(srvOrganEmpVo.getMobilePhone()) || null == srvOrganEmpVo.getEmpTypeId() || null == srvOrganEmpVo.getEmpType() || null == srvOrganEmpVo.getEduId()) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        srvOrganEmpService.saveOrUpdateSrvOrganEmp(srvOrganEmpVo);
        return Result.success();
    }

}
