package com.hungraim.ltc.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.api.AttachFeignService;
import com.hungraim.ltc.dao.*;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndAttach;
import com.hungraim.ltc.pojo.entity.assessment.ChAprTask;
import com.hungraim.ltc.pojo.entity.assessment.ChDisableInfoHis;
import com.hungraim.ltc.pojo.entity.disable.*;
import com.hungraim.ltc.pojo.entity.riskLevel.ChDisableRiskLevel;
import com.hungraim.ltc.pojo.entity.riskLevel.ChSrvorganRiskLevel;
import com.hungraim.ltc.pojo.entity.serviceManage.ChCfgPara;
import com.hungraim.ltc.pojo.vo.disable.*;
import com.hungraim.ltc.pojo.vo.system.AttachUpdateVo;
import com.hungraim.ltc.service.DisableService;
import com.hungraim.ltc.service.OrganService;
import com.hungraim.ltc.util.AttachType;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

@Service
@Slf4j
@AllArgsConstructor
public class DisableServiceImpl implements DisableService {

    private final DisableApplyMapper disableApplyMapper;
    private final FndDistrictMapper districtMapper;
    private final FndOrganMapper fndOrganMapper;
    private final FndStreetMapper fndStreetMapper;
    private final SrvModeMapper srvModeMapper;
    private final SrvOrganMapper srvOrganMapper;
    private final FndDiseaseTypeMapper fndDiseaseTypeMapper;
    private final DisableApplyHisMapper disableApplyHisMapper;
    private final DisableInfoMapper disableInfoMapper;
    private final AprTaskMapper aprTaskMapper;
    private final CfgParaMapper cfgParaMapper;
    private final AttachFeignService attachFeignService;
    private final ChDisableInfoChangeMapper chDisableInfoChangeMapper;
    private final DisableInfoHisMapper disableInfoHisMapper;
    private final OrganService organService;

    @Autowired
    private ChDisableRiskLevelMapper chDisableRiskLevelMapper;

    /**
     * 获取机构ids
     *
     * @param organId  父机构id
     * @param organIds 机构list
     */
    private void getOrganList(String organId, List<String> organIds) {
        QueryWrapper<ChFndOrgan> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("STATUS", "1");
        queryWrapper.eq("PARENT_ID", organId);
        List<ChFndOrgan> organs = fndOrganMapper.selectList(queryWrapper);
        if (organs != null && organs.size() != 0) {
            for (ChFndOrgan chFndOrgan : organs) {
                String childOrganId = chFndOrgan.getOrganId();
                organIds.add(childOrganId);
                if ("1".equals(chFndOrgan.getIsLeaf())) {
                    getOrganList(childOrganId, organIds);
                }
            }
        }
    }

    /**
     * 查询所有资源对应的角色
     *
     * @param organId            适用机构代码
     * @param districtProvincial 所在省
     * @param districtCity       所在市
     * @param districtArea       所在区域
     * @param realName           失能人员姓名
     * @param certiCode          失能人员身份证号码
     * @param dataFrom           申请来源
     * @param srvOrganName       护理机构名称
     * @param applyMethod        申请方式(1首次申请、2复评申请、3动态评估)
     * @return list
     */
    @Override
    public Page<DisableVO> disableList(Page<DisableVO> page, String organId, String districtProvincial, String districtCity,
                                       String districtArea, String realName, String certiCode, String dataFrom,
                                       String srvOrganName, Integer applyMethod) {
        // 没有organId参数的时候，这个集合就为null
        List<String> organIds = null;
        if (StrUtil.isNotBlank(organId)) {
            organIds = Arrays.asList(organId.split(","));
        }
        return disableApplyMapper.disableList(page, organIds, districtProvincial,
                districtCity, districtArea, realName, certiCode, dataFrom, srvOrganName, applyMethod);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public DisableExamineInfoVO disableExamineInfo(String applyId) {
        DisableExamineInfoVO disableExamineInfoVO = disableApplyMapper.selectDisableExamineInfoByApplyId(applyId);
        List<ExamineRecord> examineRecords = disableApplyMapper.listExamineRecordByApplyId(applyId);
        disableExamineInfoVO.setExamineRecords(examineRecords);
        try {
            // zhangch 20210525 新增返回对应的附件列表
            Result<List<ChFndAttach>> listResult = attachFeignService.selectAttachs(Long.valueOf(applyId), AttachType.DISABLE.getUploadType());
            if (listResult.getCode().equals(ResultCode.SUCCESS.getCode())) {
                disableExamineInfoVO.setFileDataList(listResult.getData());
            } else {
                log.info("请求获取附件列表错误：错误码{},错误信息:{}", listResult.getCode(), listResult.getMsg());
            }
        } catch (Exception e) {
            log.error(e.getMessage());
            e.printStackTrace();
        }
        return disableExamineInfoVO;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public DisableUpdateDetailVO disableInfoUpdateDetail(String disabInfoId) {
        ChDisableInfo chDisableInfo = disableInfoMapper.selectOne(new LambdaQueryWrapper<ChDisableInfo>().eq(ChDisableInfo::getDisabInfoId, disabInfoId));
        if (chDisableInfo != null) {
            DisableUpdateDetailVO disableUpdateDetailVo = new DisableUpdateDetailVO();
            BeanUtils.copyProperties(chDisableInfo, disableUpdateDetailVo);
            // 手动设置一些字段不一样的
            // 所在省
            disableUpdateDetailVo.setDistrictProvince(chDisableInfo.getDistrictProvincial());
            // 身份证号
            disableUpdateDetailVo.setCertifNum(chDisableInfo.getCertiCode());
            // 现住址省市区街道详细地址
            disableUpdateDetailVo.setAddressProvincial(chDisableInfo.getAdressDistrictProvincial());
            disableUpdateDetailVo.setAddressCity(chDisableInfo.getAdressDistrictCity());
            disableUpdateDetailVo.setAddressArea(chDisableInfo.getAdressDistrictCode());
            disableUpdateDetailVo.setAddressStreet(chDisableInfo.getStreet());
            disableUpdateDetailVo.setAddressDetail(chDisableInfo.getAdressDetail());
            // 接收评定详细地址
            disableUpdateDetailVo.setAcptDetail(chDisableInfo.getAcptAddress());
            // 代办人身份证号
            disableUpdateDetailVo.setOperCertiNum(chDisableInfo.getOperCertiCode());
            // 代办人省市区
            disableUpdateDetailVo.setOperProvincial(chDisableInfo.getOperDistrictProvincial());
            disableUpdateDetailVo.setOperCity(chDisableInfo.getOperDistrictCity());
            disableUpdateDetailVo.setOperArea(chDisableInfo.getOperDistrictCode());
            // 审核信息置空
            disableUpdateDetailVo.setCheckName("");
            disableUpdateDetailVo.setCheckRemark("");
//            try {
//                // TODO 需要确认信息表的附件类型
//                Result<List<ChFndAttach>> listResult = attachFeignService.selectAttachs(Long.valueOf(disabInfoId), AttachType.DISABLE.getUploadType());
//                if (listResult.getCode().equals(ResultCode.SUCCESS.getCode())) {
//                    disableUpdateDetailVo.setFileDataList(listResult.getData());
//                } else {
//                    log.info("请求获取附件列表错误：错误码{},错误信息:{}", listResult.getCode(), listResult.getMsg());
//                }
//            } catch (Exception e) {
//                log.error(e.getMessage());
//                e.printStackTrace();
//            }
            return disableUpdateDetailVo;
        }
        return null;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Result addDisable(ChDisableApply chDisableApply) {
        // 先查询当前人员有没有进行过首次申请，如果进行过就返回错误,如果当前人员有不是审核通过的复评申请，同样返回错误
        // 姓名和身份证号相同视为同一个人
        Short applyMethod = chDisableApply.getApplyMethod();
        if (Objects.equals(Short.valueOf("1"), applyMethod)) {
            // 首次申请校验
            List<ChDisableApply> chDisableApplies = disableApplyMapper.selectList(new LambdaQueryWrapper<ChDisableApply>()
                    .eq(ChDisableApply::getRealName, chDisableApply.getRealName())
                    .eq(ChDisableApply::getCertiCode, chDisableApply.getCertiCode())
                    .eq(ChDisableApply::getApplyMethod, 1));
            if (chDisableApplies.size() > 0) {
                return Result.failed("该人员已经进行了首次申请");
            }
        } else if (Objects.equals(Short.valueOf("2"), applyMethod)) {
            // 复评申请校验
            List<ChDisableApply> chDisableApplies = disableApplyMapper.selectList(new LambdaQueryWrapper<ChDisableApply>()
                    .eq(ChDisableApply::getRealName, chDisableApply.getRealName())
                    .eq(ChDisableApply::getCertiCode, chDisableApply.getCertiCode())
                    .eq(ChDisableApply::getApplyMethod, 2).ne(ChDisableApply::getApplyStatus, 2));
            if (chDisableApplies.size() > 0) {
                return Result.failed("该人员有尚未审核通过的复评申请");
            }
        }
        chDisableApply.setEffTime(new Date());
        disableApplyMapper.insert(chDisableApply);
        this.updateAttachs(chDisableApply);
        return Result.success();
    }

    /**
     * 调用feign api来修改附件数据
     *
     * @param chDisableApply
     */
    private void updateAttachs(ChDisableApply chDisableApply) {
        // zhangch 20210525 新增附件修改逻辑
        List<ChFndAttach> fileDataList = chDisableApply.getFileDataList();
        AttachUpdateVo attachUpdateVo = new AttachUpdateVo();
        attachUpdateVo.setCtrlId(chDisableApply.getApplyId());
        attachUpdateVo.setAttachType(AttachType.DISABLE.getUploadType());
        attachUpdateVo.setChFndAttachs(fileDataList);
        attachFeignService.updateAttachs(attachUpdateVo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void disableExamine(String applyId, String checkName, Short applyStatus, String checkRemark) {
        Date date = new Date();
        //更新审核状态
        ChDisableApply chDisableApply = disableApplyMapper.selectById(applyId);
        chDisableApply.setCheckName(checkName);//审核人
        chDisableApply.setApplyStatus(applyStatus);//申请状态
        chDisableApply.setCheckRemark(checkRemark);//审核备注
        chDisableApply.setCheckTime(date);//审核时间
        disableApplyMapper.updateById(chDisableApply);
        if(!applyStatus.equals(Short.valueOf("1"))){
            //添加失能审核历史
            ChDisableApplyHis chDisableApplyHis = new ChDisableApplyHis();
            BeanUtils.copyProperties(chDisableApply, chDisableApplyHis);
            disableApplyHisMapper.insert(chDisableApplyHis);
        }
        //审核通过
        if (applyStatus.equals(Short.valueOf("2"))) {
            //添加失能人员信息
            ChDisableInfo chDisableInfo = new ChDisableInfo();
            BeanUtil.copyProperties(chDisableApply, chDisableInfo);
            disableInfoMapper.insert(chDisableInfo);
            //添加失能评定信息
            ChAprTask chAprTask = new ChAprTask();
            ChCfgPara chCfgPara = cfgParaMapper.selectOne(new QueryWrapper<ChCfgPara>().eq("ORGAN_ID", chDisableApply.getOrganId()));
            if (chCfgPara != null && chCfgPara.getCfgArgTime() != null) {
                Calendar cd = Calendar.getInstance();
                cd.setTime(date);
                cd.add(Calendar.DATE, chCfgPara.getCfgArgTime().intValue());
                chAprTask.setLastAprDate(cd.getTime());//鉴定截至日期
            }
            BeanUtil.copyProperties(chDisableApply, chAprTask);
            chAprTask.setDisableInfoId(chDisableInfo.getDisabInfoId());//失能人员id
            chAprTask.setReAprStatus(0);
            chAprTask.setEffTime(new Date());
            chAprTask.setFcd(null);
            chAprTask.setAprType(0);//申请：0；复评：1
            chAprTask.setTaskStatus(0); // 任务状态 0 未分配
            aprTaskMapper.insert(chAprTask);

            ChDisableRiskLevel chDisableRiskLevel = new ChDisableRiskLevel();
            chDisableRiskLevel.setRiskLevel(0L);
            chDisableRiskLevel.setDisabInfoId(Long.valueOf(chDisableInfo.getDisabInfoId()));
            chDisableRiskLevel.setStatus(0);
            chDisableRiskLevel.setFcd(new Date());
            chDisableRiskLevelMapper.insert(chDisableRiskLevel);
        }
    }

    @Override
    public List<ChFndDistrict> district(String districtLevel, String districtCode) {
        if ("4".equals(districtLevel)) {
            //查询街道
            QueryWrapper<ChFndStreet> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("IS_VALID", 0);
            queryWrapper.eq("AREA_CODE", districtCode);
            List<ChFndStreet> fndStreets = fndStreetMapper.selectList(queryWrapper);
            List<ChFndDistrict> resuts = new ArrayList<>();
            for (ChFndStreet chFndStreet : fndStreets) {
                ChFndDistrict chFndDistrict = new ChFndDistrict();
                chFndDistrict.setDistrictCode(chFndStreet.getStreetCode());
                chFndDistrict.setDistrictName(chFndStreet.getStreetName());
                chFndDistrict.setParentDistirctCode(chFndStreet.getAreaCode());
                resuts.add(chFndDistrict);
            }
            return resuts;
        } else {
            QueryWrapper<ChFndDistrict> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("IS_VALID", "Y");
            queryWrapper.eq("DISTRICT_LEVEL", districtLevel);
            if ("1".equals(districtLevel)) {
                //查出所有的省
                return districtMapper.selectList(queryWrapper);
            } else {
                //查询市/县
                queryWrapper.eq("PARENT_DISTIRCT_CODE", districtCode);
                return districtMapper.selectList(queryWrapper);
            }
        }
    }

    @Override
    public List<ChFndOrgan> fndOrganRoot() {
        QueryWrapper<ChFndOrgan> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("IS_LEAF", "1");
        queryWrapper.eq("STATUS", "1");
        queryWrapper.and(wrapper -> wrapper.isNull("PARENT_ID").or().eq("PARENT_ID", ""));
        return fndOrganMapper.selectList(queryWrapper);
    }

    @Override
    public List<SrvModeVo> cfgSrvModeList() {
        return srvModeMapper.selectAll();
    }

    @Override
    public List<ChSrvOrgan> srvOrganList(String organId, Boolean isInvolveChild) {
        // zhangch 2021-11-04 修改查询条件 new QueryWrapper<ChSrvOrgan>().eq("organ_id", organId).eq("STATUS", (short) 0)
        List<Long> organIds = organService.getOrganIds(Long.valueOf(organId), isInvolveChild);
        return srvOrganMapper.selectList(new LambdaQueryWrapper<ChSrvOrgan>().eq(ChSrvOrgan::getStatus, (short) 0).in(ChSrvOrgan::getOrganId, organIds));
    }

    @Override
    public List<ChFndDiseaseType> fndDiseaseList(String parDiseTypeId) {
        QueryWrapper<ChFndDiseaseType> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("IS_VALID", "0");
        if (StringUtils.isNotBlank(parDiseTypeId)) {
            queryWrapper.eq("PAR_DISE_TYPE_ID", parDiseTypeId);
        } else {
            queryWrapper.and(wrapper -> wrapper.isNull("PAR_DISE_TYPE_ID").or().eq("PAR_DISE_TYPE_ID", ""));
        }
        return fndDiseaseTypeMapper.selectList(queryWrapper);
    }

    @Override
    public String subsidiariesOrganId(String organId) {
        List<String> organIds = new ArrayList<>();
        organIds.add(organId);
        // 获取子孙机构集合
        this.getOrganList(organId, organIds);
        StringBuilder sb = new StringBuilder();
        for (String o : organIds) {
            sb.append(o).append(",");
        }
        sb.deleteCharAt(sb.length() - 1);
        return sb.toString();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void updateDisable(ChDisableApply chDisableApply) {
        disableApplyMapper.updateById(chDisableApply);
        // zhangch 20210525 新增附件修改逻辑
        this.updateAttachs(chDisableApply);
    }

    @Override
    public List<DistrictTreeVo> allDistrict() {
        return districtMapper.getAllDistrictAndStreetData();
    }

    @Override
    public List<DistrictTreeVo> getAllDistrictTreeData() {
        return districtMapper.getAllDistrictTreeData();
    }

    @Override
    public List<ChFndDiseaseType> fndAllDisease() {
        QueryWrapper<ChFndDiseaseType> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("IS_VALID", "0");
        return fndDiseaseTypeMapper.selectList(queryWrapper);
    }

    @Override
    public DisableInfoVO getDisableInfo(String disableInfoId) {
        return disableApplyMapper.getDisableInfo(disableInfoId);
    }

    @Override
    public List<ChFndOrgan> fndAllOrgan() {
        QueryWrapper<ChFndOrgan> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("IS_LEAF", "1");
        queryWrapper.eq("STATUS", "1");
        return fndOrganMapper.selectList(queryWrapper);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result addOrUpdateDisInfoChange(DisableUpdateDetailVO disableUpdateDetailVO) {
        // 添加或修改记录
        Integer changeId = disableUpdateDetailVO.getChangeId();
        ChDisableInfoChange chDisableInfoChange = new ChDisableInfoChange();
        BeanUtils.copyProperties(disableUpdateDetailVO, chDisableInfoChange);
        if (null == changeId) {
            // 新增
            chDisableInfoChange.setEffTime(new Date());
            // 先校验没有正在进行中的变更
            List<ChDisableInfoChange> chDisableInfoChangesCheck = chDisableInfoChangeMapper.selectList(new LambdaQueryWrapper<ChDisableInfoChange>().eq(ChDisableInfoChange::getDisabInfoId, disableUpdateDetailVO.getDisabInfoId()).ne(ChDisableInfoChange::getApplyStatus, 2));
            if (chDisableInfoChangesCheck.size() > 0) {
                return Result.failed("无法提交，已有进行中的变更申请");
            }
            chDisableInfoChangeMapper.insert(chDisableInfoChange);
        } else {
            // 修改
            chDisableInfoChangeMapper.updateById(chDisableInfoChange);
        }
        // 同步修改附件
        List<ChFndAttach> fileDataList = disableUpdateDetailVO.getFileDataList();
        AttachUpdateVo attachUpdateVo = new AttachUpdateVo();
        attachUpdateVo.setCtrlId(chDisableInfoChange.getChangeId().longValue());
        attachUpdateVo.setAttachType(AttachType.DISABLE_UPDATE.getUploadType());
        attachUpdateVo.setChFndAttachs(fileDataList);
        attachFeignService.updateAttachs(attachUpdateVo);
        return Result.success();
    }

    @Override
    public void DisableInfoChangeExamine(String changeId, String checkName, Short applyStatus, String checkRemark) {
        Date date = new Date();
        //更新审核状态
        ChDisableInfoChange chDisableInfoChange = chDisableInfoChangeMapper.selectById(changeId);
        chDisableInfoChange.setCheckName(checkName);//审核人
        chDisableInfoChange.setApplyStatus(applyStatus);//申请状态
        chDisableInfoChange.setCheckRemark(checkRemark);//审核备注
        chDisableInfoChange.setCheckTime(date);//审核时间
        chDisableInfoChangeMapper.updateById(chDisableInfoChange);
        //审核通过
        if (applyStatus.equals(Short.valueOf("2"))) {
            // 查询出旧的失能信息
            ChDisableInfo chDisableInfo = disableInfoMapper.selectById(chDisableInfoChange.getDisabInfoId());
            // 新建disable_info_his表的一条数据，保存历史失能信息记录
            ChDisableInfoHis chDisableInfoHis = new ChDisableInfoHis();
            BeanUtil.copyProperties(chDisableInfo, chDisableInfoHis);
            disableInfoHisMapper.insert(chDisableInfoHis);
            //更新info
            ChDisableInfo newDisableInfo = new ChDisableInfo();
            BeanUtil.copyProperties(chDisableInfoChange, newDisableInfo);

            // TODO
            // 手动设置一些字段不一样的
            // 所在省
            newDisableInfo.setDistrictProvincial(chDisableInfoChange.getDistrictProvince());
            // 身份证号
            newDisableInfo.setCertiCode(chDisableInfoChange.getCertifNum());
            // 现住址省市区街道详细地址
            newDisableInfo.setAdressDistrictProvincial(chDisableInfoChange.getAddressProvincial());
            newDisableInfo.setAdressDistrictCity(chDisableInfoChange.getAddressCity());
            newDisableInfo.setAdressDistrictCode(chDisableInfoChange.getAddressArea());
            newDisableInfo.setStreet(chDisableInfoChange.getAddressStreet());
            newDisableInfo.setAdressDetail(chDisableInfoChange.getAddressDetail());
            // 接收评定详细地址
            newDisableInfo.setAcptAddress(chDisableInfoChange.getAcptDetail());
            // 代办人身份证号
            newDisableInfo.setOperCertiCode(chDisableInfoChange.getOperCertiNum());
            // 代办人省市区
            newDisableInfo.setOperDistrictProvincial(chDisableInfoChange.getOperProvincial());
            newDisableInfo.setOperDistrictCity(chDisableInfoChange.getOperCity());
            newDisableInfo.setOperDistrictCode(chDisableInfoChange.getOperArea());
            newDisableInfo.setDisabInfoId(chDisableInfo.getDisabInfoId());
            newDisableInfo.setDataFrom(1);//数据来源设置为1-信息变更
            disableInfoMapper.updateById(newDisableInfo);
        }
    }

    @Override
    public Page<DisableInfoChangeVo> ListDisInfoChangeExamine(Page<DisableInfoChangeVo> page,
                                                              Long organId, Boolean isChildGroup, String districtProvincial, String districtCity, String districtArea,
                                                              String realName, String certiCode, String aplOrganName, Short applyStatus) {
        List<Long> organIds = null;
        if (organId != null) {
            if (isChildGroup == null) {
                isChildGroup = false;
            }

            organIds = organService.getOrganIds(organId, isChildGroup);
        }
        return chDisableInfoChangeMapper.getListDisableInfoChange(page, organIds, districtProvincial
                , districtCity, districtArea, realName, certiCode, aplOrganName, applyStatus);
    }

    @Override
    public IPage<SearchDisableSimpleVo> searchByRealName(Integer pageNum, Integer pageSize, String realName) {
        IPage<ChDisableInfo> chDisableInfoPage = disableInfoMapper.selectPage(new Page<>(pageNum, pageSize), new LambdaQueryWrapper<ChDisableInfo>().like(ChDisableInfo::getRealName, realName));
        return chDisableInfoPage.convert(disableInfo -> {
            SearchDisableSimpleVo searchDisableSimpleVo = new SearchDisableSimpleVo();
            BeanUtils.copyProperties(disableInfo, searchDisableSimpleVo);
            searchDisableSimpleVo.setCertifNum(disableInfo.getCertiCode());
            return searchDisableSimpleVo;
        });
    }

    @Override
    public DisableUpdateDetailVO changeDisableDetail(Integer changeId) {
        ChDisableInfoChange chDisableInfoChange = chDisableInfoChangeMapper.selectById(changeId);
        DisableUpdateDetailVO disableUpdateDetailVO = new DisableUpdateDetailVO();
        BeanUtils.copyProperties(chDisableInfoChange, disableUpdateDetailVO);
        try {
            Result<List<ChFndAttach>> listResult = attachFeignService.selectAttachs(changeId.longValue(), AttachType.DISABLE_UPDATE.getUploadType());
            if (listResult.getCode().equals(ResultCode.SUCCESS.getCode())) {
                disableUpdateDetailVO.setFileDataList(listResult.getData());
            }
        } catch (Exception e) {
            log.error("获取失能人员变更附件失败：{}", e.getMessage());
            e.printStackTrace();
        }

        return disableUpdateDetailVO;
    }
}
