package com.hungraim.ltc.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.api.AttachFeignService;
import com.hungraim.ltc.dao.*;
import com.hungraim.ltc.pojo.entity.SysConfig.ChCfgSrvOrganType;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndAttach;
import com.hungraim.ltc.pojo.entity.SysConfig.ChFndSrvOrganLevel;
import com.hungraim.ltc.pojo.entity.disable.ChSrvOrgan;
import com.hungraim.ltc.pojo.entity.riskLevel.ChSrvorganRiskLevel;
import com.hungraim.ltc.pojo.vo.disable.SrvModeVo;
import com.hungraim.ltc.pojo.vo.disable.SrvOrganListVo;
import com.hungraim.ltc.pojo.vo.system.AttachUpdateVo;
import com.hungraim.ltc.pojo.vo.system.SrvOrganVo;
import com.hungraim.ltc.service.OrganService;
import com.hungraim.ltc.service.SrvOrganService;
import com.hungraim.ltc.util.AttachType;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service
@AllArgsConstructor
@Slf4j
public class SrvOrganServiceImpl implements SrvOrganService {

    private final SrvOrganMapper srvOrganMapper;

    private final OrganService organService;

    private final SrvModeMapper srvModeMapper;

    private final ChFndSrvOrganLevelMapper chFndSrvOrganLevelMapper;

    private final ChCfgSrvOrganTypeMapper chCfgSrvOrganTypeMapper;

    private final AttachFeignService attachFeignService;

    @Autowired
    private ChSrvorganRiskLevelMapper chSrvorganRiskLevelMapper;


    @Override
    public Page<SrvOrganListVo> getSrvOrganList(Page<SrvOrganListVo> page, Long organId, Boolean isInvolveChild, String creditCode, String srvOrganName) {
        List<Long> organIds = organService.getOrganIds(organId, isInvolveChild);
        Page<SrvOrganListVo> srvOrganList = srvOrganMapper.getSrvOrganList(page, organIds, creditCode, srvOrganName);
        List<SrvOrganListVo> records = srvOrganList.getRecords();
        if (records != null && records.size() > 0) {
            for (SrvOrganListVo srvOrganListVo : records) {
                String srvType = srvOrganListVo.getSrvType();
                if (StrUtil.isNotBlank(srvType)) {
                    String[] split = srvType.split(",");
                    List<Integer> modeIds = new ArrayList<>();
                    for (String s : split) {
                        modeIds.add(Integer.parseInt(s));
                    }
                    // 去查询对应的服务方式
                    List<SrvModeVo> srvModeVos = srvModeMapper.selectByModeIds(modeIds);
                    srvOrganListVo.setSrvModeVos(srvModeVos);
                }
            }
        }
        return srvOrganList;
    }

    @Override
    public List<ChFndSrvOrganLevel> getSrvOrganLevels() {
        return chFndSrvOrganLevelMapper.selectList(null);
    }

    @Override
    public List<ChCfgSrvOrganType> getSrvOrganTypes() {
        return chCfgSrvOrganTypeMapper.selectList(null);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void saveOrUpdateSrvOrgan(SrvOrganVo srvOrganVo) {
        Integer srvOrganId = srvOrganVo.getSrvOrganId();
        List<ChFndAttach> fileDataList = srvOrganVo.getFileDataList();
        ChSrvOrgan chSrvOrgan = new ChSrvOrgan();
        BeanUtils.copyProperties(srvOrganVo, chSrvOrgan);
        if (srvOrganId != null) {
            // 修改操作
            srvOrganMapper.updateById(chSrvOrgan);
            AttachUpdateVo attachUpdateVo = new AttachUpdateVo();
            attachUpdateVo.setCtrlId(Long.valueOf(srvOrganId));
            attachUpdateVo.setAttachType(AttachType.SRV_ORGAN.getUploadType());
            attachUpdateVo.setChFndAttachs(fileDataList);
            Result attachs = attachFeignService.updateAttachs(attachUpdateVo);
            if (!StrUtil.equals(attachs.getCode(), Result.success().getCode())) {
                log.error("同步修改文件数据失败，失败原因:{}", attachs.getMsg());
            }
        } else {
            // 添加操作
            //校验服务机构是否已存在
            ChSrvOrgan selectOrgan = srvOrganMapper.selectOne(new LambdaQueryWrapper<ChSrvOrgan>()
                    .eq(ChSrvOrgan::getOrganId, srvOrganVo.getOrganId())
                    .eq(ChSrvOrgan::getStatus, 0));
            if (selectOrgan != null) {
                throw new RuntimeException("服务机构已存在,请不要重复添加");
            }
            chSrvOrgan.setStatus(0);
            chSrvOrgan.setEffTime(new Date());
            srvOrganMapper.insert(chSrvOrgan);
            AttachUpdateVo attachUpdateVo = new AttachUpdateVo();
            attachUpdateVo.setCtrlId(Long.valueOf(chSrvOrgan.getSrvOrganId()));
            attachUpdateVo.setAttachType(AttachType.SRV_ORGAN.getUploadType());
            attachUpdateVo.setChFndAttachs(fileDataList);
            Result attachs = attachFeignService.updateAttachs(attachUpdateVo);
            if (!StrUtil.equals(attachs.getCode(), ResultCode.SUCCESS.getCode())) {
                log.error("同步修改文件数据失败，失败原因:{}", attachs.getMsg());
            }
            ChSrvorganRiskLevel chSrvorganRiskLevel = new ChSrvorganRiskLevel();
            chSrvorganRiskLevel.setRiskLevel(0L);
            chSrvorganRiskLevel.setSrvOrganId(Long.valueOf(chSrvOrgan.getSrvOrganId()));
            chSrvorganRiskLevel.setStatus(0);
            chSrvorganRiskLevel.setFcd(new Date());
            chSrvorganRiskLevelMapper.insert(chSrvorganRiskLevel);
        }
    }

    @Override
    public SrvOrganVo getSrvOrganDetail(Long srvOrganId) {
        ChSrvOrgan chSrvOrgan = srvOrganMapper.selectById(srvOrganId);
        SrvOrganVo srvOrganVo = new SrvOrganVo();
        BeanUtils.copyProperties(chSrvOrgan, srvOrganVo);
        try {
            Result<List<ChFndAttach>> listResult = attachFeignService.selectAttachs(srvOrganId, AttachType.SRV_ORGAN.getUploadType());
            if (StrUtil.equals(listResult.getCode(), ResultCode.SUCCESS.getCode())) {
                List<ChFndAttach> data = listResult.getData();
                if (data != null) {
                    srvOrganVo.setFileDataList(data);
                }
            } else {
                log.error("查询id为{}的护理机构文件列表失败，失败原因：{}", srvOrganId, listResult.getMsg());
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查询id为{}的护理机构文件列表失败，失败原因：{}", srvOrganId, e.getMessage());
        }
        return srvOrganVo;
    }

    @Override
    public void deleteSrvOrgan(Long srvOrganId) {
        ChSrvOrgan chSrvOrgan = new ChSrvOrgan();
        chSrvOrgan.setSrvOrganId(srvOrganId.intValue());
        chSrvOrgan.setStatus(1);
        srvOrganMapper.updateById(chSrvOrgan);
    }

}
