package com.hungraim.ltc.governance.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.governance.service.NursingServiceItemsService;
import com.hungraim.ltc.pojo.entity.disable.ChCfgSrvDisableLevel;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSrvOrganProject;
import com.hungraim.ltc.pojo.vo.disable.SrvModeVo;
import com.hungraim.ltc.pojo.vo.governance.OrganProjectVO;
import com.hungraim.ltc.util.Result;
import com.hungraim.ltc.util.ResultCode;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 护理服务项目配置Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.governance/nursing")
@Slf4j
public class NursingServiceItemsController {

    @Autowired
    private NursingServiceItemsService nursingServiceItemsService;

    /**
     * 护理机构护理项目配置列表
     *
     * @param organIds 机构id
     * @param name     护理服务项目名称
     * @param status   状态
     */
    @RequestMapping("/organProjectList")
    public Result<Page<OrganProjectVO>> organProjectList(@RequestParam(defaultValue = "1") Integer pageNum, @RequestParam(defaultValue = "10") Integer pageSize,
                                                         String organIds, String name, String status) {
        Page<OrganProjectVO> page = new Page<>(pageNum, pageSize);
        page = nursingServiceItemsService.organProjectList(page, organIds, name, status);
        return Result.success(page);
    }


    /**
     * 护理机构护理项目配置
     *
     * @param project 护理项目 护理项目id(如果为null就是新增,否则就是修改)
     */
    @RequestMapping("/organProjectConfig")
    public Result<Object> organProjectConfig(ChSrvOrganProject project) {
        //参数校验
        if (project.getSrvOrganId() == null || StrUtil.isBlank(project.getItemName()) || StrUtil.isBlank(project.getServiceContent()) || project.getCategoryType() == null || project.getItemPrice() == null) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        nursingServiceItemsService.organProjectConfig(project);
        return Result.success();
    }

    /**
     * 失能等级定义配置列表
     */
    @RequestMapping("/disableLevelConfigList")
    public Result<List<ChCfgSrvDisableLevel>> disableLevelConfigList() {
        List<ChCfgSrvDisableLevel> list = nursingServiceItemsService.disableLevelConfigList();
        return Result.success(list);
    }

    /**
     * 失能等级定义配置
     *
     * @param disableLevelId   失能等级定义id(如果为null就是新增,否则就是修改)
     * @param disableLevelName 失能等级定义列表 失能等级
     * @param startValue       失能等级定义列表 值1
     * @param endValue         失能等级定义列表 值2
     * @param remark           失能等级定义列表 备注
     */
    @RequestMapping("/disableLevelConfig")
    public Result<Object> disableLevelConfig(String disableLevelId, String disableLevelName, Short startValue, Short endValue, String remark) {
        //参数校验
        if (StringUtils.isBlank(disableLevelName)) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        nursingServiceItemsService.disableLevelConfig(disableLevelId, disableLevelName, startValue, endValue, remark);
        return Result.success();
    }

    /**
     * 删除失能等级数据
     *
     * @param disableLevelId 失能等级id
     * @return 返回操作状态
     */
    @DeleteMapping("/disableLevel")
    public Result delectDisableLevel(Long disableLevelId) {
        if (disableLevelId == null || disableLevelId == 0) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        nursingServiceItemsService.delectDisableLevel(disableLevelId);
        return Result.success();
    }

    /**
     * 服务方式定义配置列表
     */
    @RequestMapping("/modeConfigList")
    public Result<List<SrvModeVo>> modeConfigList() {
        List<SrvModeVo> list = nursingServiceItemsService.modeConfigList();
        return Result.success(list);
    }

    /**
     * 服务方式定义配置
     *
     * @param modeId   服务方式定义id(如果为null就是新增,否则就是修改)
     * @param modeName 服务方式定义列表 服务方式
     * @param remark   服务方式定义列表 备注
     */
    @RequestMapping("/modeConfig")
    public Result<Object> modeConfig(String modeId, String modeName, String remark) {
        //参数校验
        if (StringUtils.isBlank(modeName)) {
            return Result.failed("参数异常!");
        }
        nursingServiceItemsService.modeConfig(modeId, modeName, remark);
        return Result.success();
    }


    /**
     * 删除服务方式数据
     *
     * @param modeId 服务方式id
     * @return 返回执行结果
     */
    @DeleteMapping("/srvModel")
    public Result deleteSrvModel(Long modeId) {
        if (modeId == null || modeId == 0) {
            return Result.failed(ResultCode.REQUEST_PARAM_ERROR);
        }
        nursingServiceItemsService.deleteSrvModel(modeId);
        return Result.success();
    }

}
