package com.hungraim.ltc.governance.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hungraim.ltc.api.OrganFeignService;
import com.hungraim.ltc.governance.dao.SuperviseOrganEmpMapper;
import com.hungraim.ltc.governance.dao.SuperviseOrganMapper;
import com.hungraim.ltc.governance.service.SuperviseOrganEmpService;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSuperviseOrgan;
import com.hungraim.ltc.pojo.entity.serviceManage.ChSuperviseOrganEmp;
import com.hungraim.ltc.pojo.vo.governance.ChSuperviseOrganEmpVo;
import com.hungraim.ltc.pojo.vo.governance.SuperviseOrganEmpVO;
import com.hungraim.ltc.pojo.vo.governance.SuperviseOrganVO;
import com.hungraim.ltc.util.Result;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 监管机构人员信息管理ServiceImpl
 */
@Service
@Slf4j
@AllArgsConstructor
public class SuperviseOrganServiceImpl extends ServiceImpl<SuperviseOrganMapper, ChSuperviseOrgan> implements SuperviseOrganEmpService {
    private final SuperviseOrganEmpMapper superviseOrganEmpMapper;
    private final SuperviseOrganMapper superviseOrganMapper;
    private final OrganFeignService organFeignService;

    @Override
    public Page<SuperviseOrganEmpVO> superviseOrganEmpList(Page<SuperviseOrganEmpVO> page, Long organId, Boolean isIncluded, String organName, String superviseType, String superviseName, String superviseTel, String status) {
        return superviseOrganEmpMapper.superviseOrganEmpList(page, getOrganIds(organId, isIncluded), organName, superviseType, superviseName, superviseTel, status);
    }

    private List<Long> getOrganIds(Long organId, Boolean isIncluded) {
        Result<List<Long>> organChild = null;
        if (organId != null) {
            if (isIncluded == null) {
                isIncluded = false;
            }
            organChild = organFeignService.getOrganChild(organId, isIncluded);
            return organChild.getData();
        }
        return null;
    }

    @Override
    public void updateEmpStatus(String empId, Short isLock) {
        ChSuperviseOrganEmp chSuperviseOrganEmp = superviseOrganEmpMapper.selectById(empId);
        chSuperviseOrganEmp.setIsLock(isLock);
        superviseOrganEmpMapper.updateById(chSuperviseOrganEmp);
    }

    @Override
    public void insertOrUpdateEmpInfo(ChSuperviseOrganEmp chSuperviseOrganEmp) {
        Long spvEmpId = chSuperviseOrganEmp.getSpvEmpId();
        if (spvEmpId != null) {
            //更新
            superviseOrganEmpMapper.updateById(chSuperviseOrganEmp);
        } else {
            //新增
            chSuperviseOrganEmp.setEffTime(new Date());
            chSuperviseOrganEmp.setIsLock((short) 0);
            superviseOrganEmpMapper.insert(chSuperviseOrganEmp);
        }
    }

    @Override
    public Page<SuperviseOrganVO> superviseOrganList(Page<SuperviseOrganVO> page, Long organId, Boolean isIncluded, String spvOrganName) {
        return superviseOrganMapper.superviseOrganList(page, getOrganIds(organId, isIncluded), spvOrganName);
    }

    @Override
    public void updateSpvStatus(String spvOrganId, Short isLock) {
        ChSuperviseOrgan chSuperviseOrgan = superviseOrganMapper.selectById(spvOrganId);
        chSuperviseOrgan.setIsLock(isLock);
        superviseOrganMapper.updateById(chSuperviseOrgan);
    }

    @Override
    public void insertOrUpdateSpvInfo(ChSuperviseOrgan spvOrgan) {
        if (spvOrgan.getSpvOrganId() != null) {
            //更新
            ChSuperviseOrgan chSuperviseOrgan = superviseOrganMapper.selectById(spvOrgan);
            chSuperviseOrgan.setOrganId(spvOrgan.getOrganId());
            chSuperviseOrgan.setDistrictProvince(spvOrgan.getDistrictProvince());
            chSuperviseOrgan.setDistrictCity(spvOrgan.getDistrictCity());
            chSuperviseOrgan.setDistrictArea(spvOrgan.getDistrictArea());
            chSuperviseOrgan.setSpvOrganName(spvOrgan.getSpvOrganName());
            chSuperviseOrgan.setContactTel(spvOrgan.getContactTel());
            superviseOrganMapper.updateById(spvOrgan);
        } else {
            //新增
            spvOrgan.setIsLock((short) 0);
            spvOrgan.setEffTime(new Date());
            spvOrgan.setFcd(new Date());
            superviseOrganMapper.insert(spvOrgan);
        }
    }

    @Override
    public ChSuperviseOrgan getSuperviseOrgan(Long spvOrganId) {
        return superviseOrganMapper.selectById(spvOrganId);
    }

    @Override
    public ChSuperviseOrganEmpVo getSuperviseOrganEmp(Long spvEmpId) {
        ChSuperviseOrganEmpVo chSuperviseOrganEmpVo = new ChSuperviseOrganEmpVo();
        ChSuperviseOrganEmp chSuperviseOrganEmp = superviseOrganEmpMapper.selectById(spvEmpId);
        BeanUtils.copyProperties(chSuperviseOrganEmp, chSuperviseOrganEmpVo);
        ChSuperviseOrgan chSuperviseOrgan = superviseOrganMapper.selectById(chSuperviseOrganEmp.getSpvOrganId());
        chSuperviseOrganEmpVo.setOrganId(chSuperviseOrgan.getOrganId());
        return chSuperviseOrganEmpVo;
    }
}
