package com.hungraim.ltc.system.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.pojo.entity.system.SystemRole;
import com.hungraim.ltc.pojo.entity.system.SystemRoleResource;
import com.hungraim.ltc.pojo.vo.system.ReqRoleInfo;
import com.hungraim.ltc.system.service.ISystemRoleResourceService;
import com.hungraim.ltc.system.service.ISystemRoleService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author hubin
 */
@RestController
@RequestMapping("/api.system/role")
@Slf4j
public class RoleController {

    @Autowired
    private ISystemRoleResourceService roleResourceService;
    @Autowired
    private ISystemRoleService roleService;


    /**
     * 根据权限id获取相应的资源id
     *
     * @param roleIds
     * @return
     */
    @PostMapping("/getRoleResource")
    public Result getRoleResource(@RequestParam List<String> roleIds) {
        List<Long> list = roleResourceService.list(new LambdaQueryWrapper<SystemRoleResource>().in(
            SystemRoleResource::getRoleId, roleIds
        )).stream().map(SystemRoleResource::getResourceId).collect(Collectors.toList());
        return Result.success(list);
    }

    @PostMapping("/addRole")
    public Result addRole(ReqRoleInfo reqRoleInfo) {

        if (StrUtil.isBlankIfStr(reqRoleInfo.getName())) {
            return Result.failed("角色名称不能为空！");
        }

        SystemRole role = roleService.getOne(new LambdaQueryWrapper<SystemRole>()
            .eq(SystemRole::getRoleName, reqRoleInfo.getName()));

        if (role != null) {
            return Result.failed("角色名称不能重复！");
        }

        SystemRole systemRole = new SystemRole();
        systemRole.setRoleName(reqRoleInfo.getName());
        systemRole.setStatus(reqRoleInfo.getStatus());
        systemRole.setCreatedTime(new Date());
        roleService.save(systemRole);
        Long roleId = systemRole.getRoleId();
        if(reqRoleInfo.getResource() == null){
            reqRoleInfo.setResource(new ArrayList<>());
        }
        List<SystemRoleResource> roleResources = reqRoleInfo.getResource().stream().map(resourceId -> {
            SystemRoleResource systemRoleResource = new SystemRoleResource();
            systemRoleResource.setRoleId(roleId);
            systemRoleResource.setResourceId(resourceId);
            return systemRoleResource;
        }).collect(Collectors.toList());
        roleResourceService.saveBatch(roleResources);

        return Result.success("新增成功");

    }

    /**
     * 判断是否合法
     *
     * @param roleName
     * @return
     */
    @GetMapping("/isLegitimate/{roleName}")
    public Result isLegitimate(@PathVariable String roleName) {
        if (StrUtil.isBlankIfStr(roleName)) {
            return Result.failed("名称不能为空！");
        }
        SystemRole systemRole = roleService.getOne(new LambdaQueryWrapper<SystemRole>()
            .eq(SystemRole::getRoleName, roleName));
        if (systemRole != null) {
            return Result.failed("名称已存在！");
        }
        return Result.success("成功");
    }

    /**
     * 查询角色列表
     *
     * @param reqRoleInfo
     * @return
     */
    @PostMapping("/queryRoles")
    public Result queryRoles(ReqRoleInfo reqRoleInfo,
                             @RequestParam(defaultValue = "1") int pageNum, @RequestParam(defaultValue = "20") int pageSize) {
        QueryWrapper<SystemRole> systemRoleQueryWrapper = new QueryWrapper<>();

        if (!StrUtil.isBlankIfStr(reqRoleInfo.getName())) {
            systemRoleQueryWrapper.and(wrapper -> wrapper.lambda().like(SystemRole::getRoleName, reqRoleInfo.getName()));
        }
        if (!StrUtil.isBlankIfStr(reqRoleInfo.getStatus())) {
            systemRoleQueryWrapper.and(wrapper -> wrapper.lambda().eq(SystemRole::getStatus, reqRoleInfo.getStatus()));
        }
        systemRoleQueryWrapper.orderByAsc("role_id");

        return Result.success(roleService.page(new Page<>(pageNum, pageSize), systemRoleQueryWrapper));
    }

    /**
     * 更新角色信息
     *
     * @param reqRoleInfo
     * @return
     */
    @PostMapping("/updateRole")
    public Result updateRole(ReqRoleInfo reqRoleInfo) {
        if (reqRoleInfo.getId() == null) {
            return Result.failed("角色ID无效！");
        }
        SystemRole systemRole = roleService.getOne(new LambdaQueryWrapper<SystemRole>().eq(SystemRole::getRoleId, reqRoleInfo.getId()));
        if (systemRole == null) {
            return Result.failed("角色ID无效！");
        }
        boolean flag = false;
        if (!reqRoleInfo.getName().equals(systemRole.getRoleName())) {
            systemRole.setRoleName(reqRoleInfo.getName());
            flag = true;
        }
        if (!reqRoleInfo.getStatus().equals(systemRole.getStatus())) {
            systemRole.setStatus(reqRoleInfo.getStatus());
            flag = true;
        }
        if (flag) {
            systemRole.setUpdatedTime(new Date());
            roleService.updateById(systemRole);
        }

        //查询该角色下所有的资源数据
        List<SystemRoleResource> roleResources = roleResourceService.list(new LambdaQueryWrapper<SystemRoleResource>().eq(SystemRoleResource::getRoleId, reqRoleInfo.getId()));

        if(reqRoleInfo.getResource()==null){
            reqRoleInfo.setResource(new ArrayList<>());
        }
        List<SystemRoleResource> newRoleResources = reqRoleInfo.getResource().stream()
            .filter(id -> {
                for (SystemRoleResource r : roleResources) {
                    if (r.getResourceId().equals(id)) {
                        return false;
                    }
                }
                return true;
            }).map(resourceId -> {
                SystemRoleResource systemRoleResource = new SystemRoleResource();
                systemRoleResource.setResourceId(resourceId);
                systemRoleResource.setRoleId(reqRoleInfo.getId());
                return systemRoleResource;
            }).collect(Collectors.toList());
        roleResourceService.saveBatch(newRoleResources);

        List<Long> deleteRoleResources = roleResources.stream()
            .map(SystemRoleResource::getResourceId).filter(resourceId -> !reqRoleInfo.getResource().contains(resourceId))
            .collect(Collectors.toList());
        roleResourceService.removeByIds(deleteRoleResources);
        return Result.success("更新成功");
    }


}
